==> nextcloud-app-mail-5.3.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/be.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Праца",
    "Mail" : "Пошта",
    "Save" : "Захаваць",
    "Name" : "Назва",
    "name@example.org" : "name@example.org",
    "Password" : "Пароль",
    "IMAP Settings" : "Налады IMAP",
    "IMAP Host" : "Хост IMAP",
    "IMAP Security" : "Бяспека IMAP",
    "None" : "Няма",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Порт IMAP",
    "IMAP User" : "Карыстальнік IMAP",
    "IMAP Password" : "Пароль IMAP",
    "SMTP Settings" : "Налады SMTP",
    "SMTP Host" : "Хост SMTP",
    "SMTP Security" : "Бяспека SMTP",
    "SMTP Port" : "Порт SMTP",
    "SMTP User" : "Карыстальнік SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Signature" : "Подпіс",
    "Default folders" : "Прадвызначаныя папкі",
    "Filters" : "Фільтры",
    "Go back" : "Назад",
    "Email address" : "Адрас электроннай пошты",
    "Cancel" : "Скасаваць",
    "Accounts" : "Уліковыя запісы",
    "General" : "Агульныя",
    "Sorting" : "Сартаванне",
    "Privacy and security" : "Прыватнасць і бяспека",
    "S/MIME" : "S/MIME",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "Archive" : "Архіў",
    "Delete" : "Выдаліць",
    "Search" : "Пошук",
    "Send" : "Адправіць",
    "Refresh" : "Абнавіць",
    "Ok" : "ОК",
    "From" : "Ад",
    "Select account" : "Выберыце ўліковы запіс",
    "To" : "Каму",
    "Cc/Bcc" : "Cc/Bcc",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Тэма",
    "Subject …" : "Тэма …",
    "Saving draft …" : "Захаванне чарнавіка …",
    "Error saving draft" : "Памылка пры захаванні чарнавіка",
    "Draft saved" : "Чарнавік захаваны",
    "Save draft" : "Захаваць чарнавік",
    "Discard & close draft" : "Адхіліць і закрыць чарнавік",
    "Enable formatting" : "Уключыць фарматаванне",
    "Disable formatting" : "Выключыць фарматаванне",
    "Enter a date" : "Увядзіце дату",
    "Choose" : "Выбраць",
    "Confirm" : "Пацвердзіць",
    "Rich text" : "Фарматаваны тэкст",
    "No messages in this folder" : "У гэтай папцы няма паведамленняў",
    "No messages" : "Няма паведамленняў",
    "Encrypted message" : "Зашыфраванае паведамленне",
    "Favorite" : "Абранае",
    "Read" : "Чытаць",
    "Edit tags" : "Рэдагаваць тэгі",
    "Delete message" : "Выдаліць паведамленне",
    "More actions" : "Больш дзеянняў",
    "Back" : "Назад",
    "Description" : "Апісанне",
    "Create" : "Стварыць",
    "Select" : "Выбраць",
    "Comment" : "Каментарый",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "Remove" : "Выдаліць",
    "Last hour" : "Апошняя гадзіна",
    "Today" : "Сёння",
    "Yesterday" : "Учора",
    "Last week" : "Мінулы тыдзень",
    "Last month" : "Мінулы месяц",
    "Choose target folder" : "Выберыце мэтавую папку",
    "Forward" : "Пераслаць",
    "Move message" : "Перамясціць паведамленне",
    "Translate" : "Перакласці",
    "Unnamed" : "Без назвы",
    "Download Zip" : "Спампаваць Zip",
    "Move" : "Перамясціць",
    "Remove account" : "Выдаліць уліковы запіс",
    "Remove {email}" : "Выдаліць {email}",
    "Add folder" : "Дадаць папку",
    "Folder name" : "Назва папкі",
    "Move up" : "Перамясціць уверх",
    "Move down" : "Перамясціць уніз",
    "Show all folders" : "Паказаць усе папкі",
    "_{total} message_::_{total} messages_" : ["{total} паведамленне","{total} паведамленні","{total} паведамленняў","{total} паведамленняў"],
    "Loading …" : "Загрузка …",
    "Clear folder" : "Ачысціць папку",
    "Delete folder" : "Выдаліць папку",
    "Delete folder {name}" : "Выдаліць папку {name}",
    "Add subfolder" : "Дадаць падпапку",
    "Rename" : "Перайменаваць",
    "Move folder" : "Перамясціць папку",
    "Clear cache" : "Ачысціць кэш",
    "Translate this message to {language}" : "Перакласці гэта паведамленне на {language}",
    "New message" : "Новае паведамленне",
    "Edit message" : "Рэдагаваць паведамленне",
    "Draft" : "Чарнавік",
    "Reply" : "Адказаць",
    "Message saved" : "Паведамленне захавана",
    "Failed to save message" : "Не ўдалося захаваць паведамленне",
    "Failed to save draft" : "Не ўдалося захаваць чарнавік",
    "attachment" : "далучэнне",
    "Message discarded" : "Паведамленне адхілена",
    "Could not discard message" : "Не ўдалося адхіліць паведамленне",
    "Retry" : "Паўтарыць спробу",
    "Message" : "Паведамленне",
    "Copy to clipboard" : "Капіяваць у буфер абмену",
    "Add" : "Дадаць",
    "Clear" : "Ачысціць",
    "Close" : "Закрыць",
    "Date" : "Дата",
    "Tags" : "Тэгі",
    "Last 7 days" : "Апошнія 7 дзён",
    "Not found" : "Не знойдзена",
    "Please select languages to translate to and from" : "Выберыце, з якой мовы на якую перакладаць",
    "The message could not be translated" : "Не ўдалося перакласці паведамленне ",
    "Translation copied to clipboard" : "Пераклад скапіяваны ў буфер абмену",
    "Translation could not be copied" : "Не ўдалося скапіяваць пераклад",
    "Translate message" : "Перакласці паведамленне",
    "Source language to translate from" : "Зыходная мова для перакладу",
    "Translate from" : "Перакласці з",
    "Target language to translate into" : "Мэтавая мова для перакладу",
    "Translate to" : "Перакласці на",
    "Translating" : "Пераклад",
    "Copy translated text" : "Скапіяваць перакладзены тэкст",
    "Train" : "Цягнік",
    "Flag" : "Сцяг",
    "Delete filter" : "Выдаліць фільтр",
    "Operator" : "Аператар",
    "Reset" : "Скінуць",
    "Client ID" : "Ідэнтыфікатар кліента",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} (шыфраванне {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} (шыфравенне {ssl})",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} на {host}:{port} (шыфраванне {ssl})",
    "Email address template" : "Шаблон адраса электроннай пошты",
    "IMAP" : "IMAP",
    "User" : "Карыстальнік",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "S/MIME certificates" : "Сертыфікаты S/MIME",
    "Certificate name" : "Назва сертыфіката",
    "E-mail address" : "Адрас электроннай пошты",
    "Delete certificate" : "Выдаліць сертыфікат",
    "PKCS #12 Certificate" : "Сертыфікат PKCS #12",
    "PEM Certificate" : "Сертыфікат PEM",
    "Certificate" : "Сертыфікат",
    "Submit" : "Адправіць",
    "Guest" : "Госць",
    "Group" : "Група",
    "Shared" : "Абагуленыя",
    "Edit {title}" : "Рэдагаваць {title}",
    "Delete {title}" : "Выдаліць {title}",
    "Insert" : "Уставіць",
    "All" : "Усе",
    "Drafts" : "Чарнавікі",
    "Favorites" : "Абранае",
    "Priority inbox" : "Прыярытэтныя",
    "Inbox" : "Уваходныя",
    "Sent" : "Адпраўленыя",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новае паведамленне \nад {from}","%n новыя паведамленні \nад {from}","%n новых паведамленняў \nад {from}","%n новых паведамленняў \nад {from}"],
    "Discard changes" : "Адхіліць змены",
    "Discard unsaved changes" : "Адхіліць незахаваныя змены",
    "Sending message…" : "Адпраўка паведамлення…",
    "Message sent" : "Паведамленне адпраўлена",
    "Could not send message" : "Не атрымалася адправіць паведамленне",
    "Message copied to \"Sent\" folder" : "Паведамленне скапіявана ў папку \"Адпраўленыя\"",
    "Could not copy message to \"Sent\" folder" : "Не ўдалося скапіяваць паведамленне ў папку \"Адпраўленыя\"",
    "Could not load {tag}{name}{endtag}" : "Не ўдалося загрузіць {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Узнікла праблема з загрузкай {tag}{name}{endtag}",
    "Could not load your message" : "Не ўдалося загрузіць ваша паведамленне",
    "Could not load the message" : "Не ўдалося загрузіць паведамленне",
    "Error loading message" : "Памылка пры загрузцы паведамлення"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-mail-5.3.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/be.js <==
OC.L10N.register(
    "mail",
    {
    "Work" : "Праца",
    "Mail" : "Пошта",
    "You are reaching your mailbox quota limit for {account_email}" : "Вы дасягаеце ліміту квоты вашай паштовай скрынкі для {account_email} ",
    "Save" : "Захаваць",
    "Name" : "Назва",
    "name@example.org" : "name@example.org",
    "Password" : "Пароль",
    "IMAP Settings" : "Налады IMAP",
    "IMAP Host" : "Хост IMAP",
    "IMAP Security" : "Бяспека IMAP",
    "None" : "Няма",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Порт IMAP",
    "IMAP User" : "Карыстальнік IMAP",
    "IMAP Password" : "Пароль IMAP",
    "SMTP Settings" : "Налады SMTP",
    "SMTP Host" : "Хост SMTP",
    "SMTP Security" : "Бяспека SMTP",
    "SMTP Port" : "Порт SMTP",
    "SMTP User" : "Карыстальнік SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Signature" : "Подпіс",
    "Default folders" : "Прадвызначаныя папкі",
    "Filters" : "Фільтры",
    "Go back" : "Назад",
    "Email address" : "Адрас электроннай пошты",
    "Cancel" : "Скасаваць",
    "Accounts" : "Уліковыя запісы",
    "General" : "Агульныя",
    "Sorting" : "Сартаванне",
    "Privacy and security" : "Прыватнасць і бяспека",
    "S/MIME" : "S/MIME",
    "About" : "Аб гэтым",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "Archive" : "Архіў",
    "Delete" : "Выдаліць",
    "Search" : "Пошук",
    "Send" : "Адправіць",
    "Refresh" : "Абнавіць",
    "Ok" : "ОК",
    "From" : "Ад",
    "Select account" : "Выберыце ўліковы запіс",
    "To" : "Каму",
    "Cc/Bcc" : "Cc/Bcc",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Тэма",
    "Subject …" : "Тэма …",
    "Saving draft …" : "Захаванне чарнавіка …",
    "Error saving draft" : "Памылка пры захаванні чарнавіка",
    "Draft saved" : "Чарнавік захаваны",
    "Save draft" : "Захаваць чарнавік",
    "Discard & close draft" : "Адхіліць і закрыць чарнавік",
    "Enable formatting" : "Уключыць фарматаванне",
    "Disable formatting" : "Выключыць фарматаванне",
    "Enter a date" : "Увядзіце дату",
    "Choose" : "Выбраць",
    "Confirm" : "Пацвердзіць",
    "Rich text" : "Фарматаваны тэкст",
    "No messages in this folder" : "У гэтай папцы няма паведамленняў",
    "No messages" : "Няма паведамленняў",
    "Encrypted message" : "Зашыфраванае паведамленне",
    "Favorite" : "Абранае",
    "Read" : "Чытаць",
    "Edit tags" : "Рэдагаваць тэгі",
    "Delete message" : "Выдаліць паведамленне",
    "More actions" : "Больш дзеянняў",
    "Back" : "Назад",
    "Description" : "Апісанне",
    "Create" : "Стварыць",
    "Select" : "Выбраць",
    "Comment" : "Каментарый",
    "Accept" : "Прыняць",
    "Decline" : "Адхіліць",
    "Remove" : "Выдаліць",
    "Last hour" : "Апошняя гадзіна",
    "Today" : "Сёння",
    "Yesterday" : "Учора",
    "Last week" : "Мінулы тыдзень",
    "Last month" : "Мінулы месяц",
    "Choose target folder" : "Выберыце мэтавую папку",
    "Forward" : "Пераслаць",
    "Move message" : "Перамясціць паведамленне",
    "Translate" : "Перакласці",
    "Unnamed" : "Без назвы",
    "Download Zip" : "Спампаваць Zip",
    "Move" : "Перамясціць",
    "Used quota: {quota}% ({limit})" : "Выкарыстана квота: {quota}% ({limit})",
    "Used quota: {quota}%" : "Выкарыстана квота: {quota}%",
    "Remove account" : "Выдаліць уліковы запіс",
    "Remove {email}" : "Выдаліць {email}",
    "Add folder" : "Дадаць папку",
    "Folder name" : "Назва папкі",
    "Move up" : "Перамясціць уверх",
    "Move down" : "Перамясціць уніз",
    "Show all folders" : "Паказаць усе папкі",
    "_{total} message_::_{total} messages_" : ["{total} паведамленне","{total} паведамленні","{total} паведамленняў","{total} паведамленняў"],
    "Loading …" : "Загрузка …",
    "Clear folder" : "Ачысціць папку",
    "Delete folder" : "Выдаліць папку",
    "Delete folder {name}" : "Выдаліць папку {name}",
    "Add subfolder" : "Дадаць падпапку",
    "Rename" : "Перайменаваць",
    "Move folder" : "Перамясціць папку",
    "Clear cache" : "Ачысціць кэш",
    "Translate this message to {language}" : "Перакласці гэта паведамленне на {language}",
    "New message" : "Новае паведамленне",
    "Edit message" : "Рэдагаваць паведамленне",
    "Draft" : "Чарнавік",
    "Reply" : "Адказаць",
    "Message saved" : "Паведамленне захавана",
    "Failed to save message" : "Не ўдалося захаваць паведамленне",
    "Failed to save draft" : "Не ўдалося захаваць чарнавік",
    "attachment" : "далучэнне",
    "Message discarded" : "Паведамленне адхілена",
    "Could not discard message" : "Не ўдалося адхіліць паведамленне",
    "Retry" : "Паўтарыць спробу",
    "Message" : "Паведамленне",
    "Copy to clipboard" : "Капіяваць у буфер абмену",
    "Add" : "Дадаць",
    "Clear" : "Ачысціць",
    "Close" : "Закрыць",
    "Date" : "Дата",
    "Tags" : "Тэгі",
    "Last 7 days" : "Апошнія 7 дзён",
    "Custom" : "Скарыстаць",
    "Not found" : "Не знойдзена",
    "Newest message" : "Апошняе паведамленне",
    "Please select languages to translate to and from" : "Выберыце, з якой мовы на якую перакладаць",
    "The message could not be translated" : "Не ўдалося перакласці паведамленне ",
    "Translation copied to clipboard" : "Пераклад скапіяваны ў буфер абмену",
    "Translation could not be copied" : "Не ўдалося скапіяваць пераклад",
    "Translate message" : "Перакласці паведамленне",
    "Source language to translate from" : "Зыходная мова для перакладу",
    "Translate from" : "Перакласці з",
    "Target language to translate into" : "Мэтавая мова для перакладу",
    "Translate to" : "Перакласці на",
    "Translating" : "Пераклад",
    "Copy translated text" : "Скапіяваць перакладзены тэкст",
    "Train" : "Цягнік",
    "Flag" : "Сцяг",
    "Delete filter" : "Выдаліць фільтр",
    "Operator" : "Аператар",
    "Reset" : "Скінуць",
    "Client ID" : "Ідэнтыфікатар кліента",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} (шыфраванне {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} (шыфравенне {ssl})",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} на {host}:{port} (шыфраванне {ssl})",
    "Email address template" : "Шаблон адраса электроннай пошты",
    "IMAP" : "IMAP",
    "User" : "Карыстальнік",
    "Host" : "Хост",
    "Port" : "Порт",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "S/MIME certificates" : "Сертыфікаты S/MIME",
    "Certificate name" : "Назва сертыфіката",
    "E-mail address" : "Адрас электроннай пошты",
    "Delete certificate" : "Выдаліць сертыфікат",
    "PKCS #12 Certificate" : "Сертыфікат PKCS #12",
    "PEM Certificate" : "Сертыфікат PEM",
    "Certificate" : "Сертыфікат",
    "Submit" : "Адправіць",
    "Guest" : "Госць",
    "Group" : "Група",
    "Shared" : "Абагуленыя",
    "Edit {title}" : "Рэдагаваць {title}",
    "Delete {title}" : "Выдаліць {title}",
    "Insert" : "Уставіць",
    "All" : "Усе",
    "Drafts" : "Чарнавікі",
    "Favorites" : "Абранае",
    "Priority inbox" : "Прыярытэтныя",
    "Inbox" : "Уваходныя",
    "Sent" : "Адпраўленыя",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новае паведамленне \nад {from}","%n новыя паведамленні \nад {from}","%n новых паведамленняў \nад {from}","%n новых паведамленняў \nад {from}"],
    "Discard changes" : "Адхіліць змены",
    "Discard unsaved changes" : "Адхіліць незахаваныя змены",
    "Sending message…" : "Адпраўка паведамлення…",
    "Message sent" : "Паведамленне адпраўлена",
    "Could not send message" : "Не атрымалася адправіць паведамленне",
    "Message copied to \"Sent\" folder" : "Паведамленне скапіявана ў папку \"Адпраўленыя\"",
    "Could not copy message to \"Sent\" folder" : "Не ўдалося скапіяваць паведамленне ў папку \"Адпраўленыя\"",
    "Could not load {tag}{name}{endtag}" : "Не ўдалося загрузіць {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Узнікла праблема з загрузкай {tag}{name}{endtag}",
    "Could not load your message" : "Не ўдалося загрузіць ваша паведамленне",
    "Could not load the message" : "Не ўдалося загрузіць паведамленне",
    "Error loading message" : "Памылка пры загрузцы паведамлення"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
